# Algowrap

A wrapper around your analysis.

##Introduction

This package serves as a wrapper around your analysis algorithm for
a system level abstraction.

This package provides the following functionality:

- Downloading required input files for the algorithm
- Uploading output files to s3
- Error handling and logging
- Logging
- Database updates

## Getting Started

Clone the repository or install using pip:
```
pip install --upgrade algowrap
```

### Prerequisites

Elucidata's privately maintained pip server should be configured properly to
install via pip. Also, you need to be on the Elucidata's static IP for this to
work.

In ~/.pip/pip.conf on Mac/Linux, add:
```
[global]
extra-index-url = http://54.245.179.143/
[install]
trusted-host=54.245.179.143
```

### Installing

Create a linker function that runs a desired algorithm based on input:

```
def link_run_analysis_func(parameter_data, input_local_files):
    output_data_object = None
    if "algorithm" not in parameter_data:
        raise SomeError(...)
    else:
        algorithm = parameter_data.get("algorithm")

    if algorithm == 'file_validation':
        output_data_object = algorithm_wrapper(func1, parameter_data, input_local_files)
    elif algorithm == '...'
        output_data_object = algorithm_wrapper(func2, parameter_data, input_local_files)
    ...
    ...

    return output_data_object
```

Import and run the run_algorithm function:

```
from algowrap import run_algorithm

if __name__ == "__main__":
    run_algorithm(link_run_analysis_func)
```

The algowrap will handle all input and output intensive tasks and handling
of errors.

## Deployment`

Just install algowrap as pip/python dependency in your algorithm/setu layer.

## Adding a new error
err_constants.py contains error codes with correspondng error messages. If the 
error you want to add in your code is not in err_constants, first classify the group 
of the error. 
For example, lets say the error you want to display is an input error. Then,
INPUTERR10_YOUR_ERROR = "INPUTERR10: Your error message".

## Built With

* [Requests](http://docs.python-requests.org/en/master/) - HTTP/1.1 requests package for python
* [Pandas](https://pandas.pydata.org/pandas-docs/stable/) - Data analysis toolkit
* [Sentry](https://sentry.io) - Real time error tracking.
* Love

## Versioning

We use [SemVer](http://semver.org/) for versioning.

## License

This project is developed and maintained internally by Elucidata Inc.
